import os
import matplotlib.pyplot as plt
import numpy as np
from utils import results, kinematics

title = 'f_5.5'
path = './files/vs_ldvm/semi_active/' + title + '/'
output_ldvm_name = 'output_comp.dat'

b = 1.0
c = 0.25
surface = b * c
u_inf = 10.0
rho = 1.225

h = np.load(path + 'h.npy') / c
theta = np.degrees(np.load(path + 'theta.npy'))
time = np.load(path + 'time.npy')
time = time - time[0]


kinematics_obj = kinematics.Kinematics(kinematics_reference=1,
                                       nb_time_step_per_period=1000,
                                       input_variable_names=["x_f", "f", "theta_0"],
                                       output_variable_names=["lift_coefficient", "moment_coefficient"],
                                       variable_values=[0.0, 1.0, 0.0],
                                       heaving_amplitude_chord=0.0,
                                       m=3,
                                       tau=9,
                                       input_time_arr=time,
                                       input_h_arr=h,
                                       input_theta_arr=theta)

new_h = np.zeros(np.size(time))
new_theta = np.zeros(np.size(time))

for i in range(np.size(time)):
    tmp_theta, tmp_h = kinematics_obj.kinematics_function(time[i])
    new_theta[i] = tmp_theta
    new_h[i] = tmp_h

plt.figure()
plt.plot(time, theta)
plt.plot(time, new_theta, linestyle='dashed')

plt.figure()
plt.plot(time, h)
plt.plot(time, new_h, linestyle='dashed')

plt.show()