import os
import cv2
import matplotlib.pyplot as plt
import numpy as np
import tqdm
from utils import plots

debug = False

u_inf = 10.0
m = 1.9
theta_0 = 79.5
xf_c = 0.32
chord = 0.25

params_path = './files/params/'
model_name = 'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_5'
params_model_path = params_path + model_name + '/'
figures_path = params_model_path + 'figures/'

paths = os.listdir(params_model_path)
if 'figures' in paths:
    paths.remove('figures')

frequencies = paths

for i in range(len(paths)):
    frequencies[i] = frequencies[i][2:]

if '1.0' in frequencies:
    frequencies.remove('1.0')
if '1.5' in frequencies:
    frequencies.remove('1.5')

frequencies = np.sort(np.array(paths, dtype=float))
paths = np.array([], dtype=str)

for i in range(len(frequencies)):
    paths = np.append(paths, 'f_' + str(frequencies[i]) + '/')

if not os.path.exists(figures_path):
    os.mkdir(figures_path)

video_out = None

for i in tqdm.tqdm(range(len(frequencies))):
    frequency = frequencies[i]
    input_array = np.load(params_model_path + paths[i] + 'input_array.npy')
    efficiency = np.load(params_model_path + paths[i] + 'efficiency.npy')

    v_min = 0.0
    v_max = 0.5

    reduced_frequency = ((2 * np.pi * frequency) * (chord / 2)) / u_inf

    title = 'Step 4 | $U_{\\infty} = $' + str(u_inf) + ' $m.s^{-1}$ | $m = ' + str(m) + '$ $kg.m^{-1}$' + " | $k = $" + str(np.round(reduced_frequency, 3)) + ' | $\\theta_0 = $' + str(np.round(theta_0, 2)) + '$^{\\circ}$ | $x_f/c = $' + str(xf_c)

    save_path = figures_path + 'f_' + str(frequency) + '.png'

    plots.plot_3d(x_arr=input_array,
                  Z=efficiency,
                  v_min=v_min,
                  v_max=v_max,
                  label=['$C_h$ ($N.s.m^{-2}$)', '$K_h$ ($N.m^{-2}$)', '$\\eta$'],
                  suptitle=title,
                  save_path=save_path)

    img = cv2.imread(save_path)

    frameSize = (np.size(img, 1), np.size(img, 0))

    if i == 0:
        video_out = cv2.VideoWriter(figures_path + 'video.mp4', cv2.VideoWriter_fourcc(*'mp4v'), 2, frameSize)

    video_out.write(img)

    if debug:
        plt.show()

video_out.release()



#


