import os
import matplotlib.pyplot as plt
import numpy as np

from utils import results, kinematics


def setup_kinematics(non_dimensional_time, theta_in_degrees, h_c, path):
    u = np.ones(np.size(non_dimensional_time))

    export = np.zeros((len(non_dimensional_time), 4), dtype=np.float32)
    export[:, 0] = np.round(non_dimensional_time, 8)
    export[:, 1] = np.round(theta_in_degrees, 8)
    export[:, 2] = np.round(h_c, 8)
    export[:, 3] = np.round(u, 8)

    export = np.round(export, 8)
    np.savetxt(path + '/inputs_kinematics_ldvm.dat', export, delimiter="   ", fmt='%.7e', newline="\n   ")

title = 'f_6.54'
path = './files/vs_ldvm/semi_active/' + title + '/'
output_ldvm_name = 'output_comp.dat'

b = 1.0
c = 0.25
surface = b * c
u_inf = 10.0
rho = 1.225

h = np.load(path + 'h.npy') / c
theta = np.degrees(np.load(path + 'theta.npy'))
time = np.load(path + 'time.npy')
time = time - time[0]

if not os.path.isfile(path + output_ldvm_name):
    time_input_tmp = (time * u_inf) / c

    time_input, theta = results.interp_arr(time_input_tmp, theta, 500)
    time_input, h = results.interp_arr(time_input_tmp, h, 500)

    plt.figure()
    plt.plot(time_input, h)
    plt.grid()

    setup_kinematics(time_input, theta, h, path)

else:
    output_data = np.loadtxt(path + 'output_comp.dat')

    skip = 5

    time_simu = output_data[skip:, 0]
    cl = output_data[skip:, 8]
    cd = output_data[skip:, 9]
    cm = output_data[skip:, 10]

    lift = np.load(path + 'lift.npy')
    moment = np.load(path + 'moment.npy')

    lift_coefficient = lift / (0.5 * rho * (u_inf ** 2) * surface)
    moment_coefficient = moment / (0.5 * rho * (u_inf ** 2) * surface * c)

    plt.figure()
    plt.plot(time, h)
    plt.xlabel('Time ($s$)')
    plt.ylabel('$\\frac{h}{c}$')
    plt.grid()

    plt.figure()
    plt.plot(time_simu, cl, label='LDVM')
    plt.plot(time, lift_coefficient, label='MLP')
    plt.xlabel('Time ($s$)')
    plt.ylabel('$C_L$')
    plt.grid()
    plt.legend()
    plt.title(title)
    plt.savefig(path + 'comp_lift.png')

    plt.figure()
    plt.plot(time_simu, cm, label='LDVM')
    plt.plot(time, moment_coefficient, label='MLP')
    plt.xlabel('Time ($s$)')
    plt.ylabel('$C_M$')
    plt.grid()
    plt.legend()
    plt.title(title)
    plt.savefig(path + 'comp_moment.png')

    plt.show()



