import numpy as np
import torch

from utils import dataset, mlp

dataset_name = 'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_3'
model_name = 'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_2'

m = 3
tau = 9
nb_time_steps = 1000

nb_time_steps_dataset = nb_time_steps - ((m - 1) * tau)

inputs_variables = ["x_f", "f", "theta_0"]
outputs_variable = ["lift_coefficient", "moment_coefficient"]

range_variables = np.array([[1.0, 8.0, 10], [0.5, 40.0, 25], [5.0, 5000.0, 40]])

nb_cases_train_dataset = 9000
nb_cases_test_dataset = 500
nb_cases_validation_dataset = 500

n_input, n_output, layers_configuration = mlp.load_parameters(neural_networks_path='mlp/files/neural_networks/',
                                                              model_name=model_name)

model = mlp.MLP(n_input=n_input,
                n_output=n_output,
                layers_configuration=layers_configuration)

model.load_state_dict(torch.load('mlp/files/neural_networks/' + model_name + '/model_' + model_name + '.pt',
                                 weights_only=True))
model.eval()

dataset.generate(nb_time_steps,
                 nb_time_steps_dataset,
                 inputs_variables,
                 outputs_variable,
                 range_variables,
                 nb_cases_train_dataset,
                 nb_cases_test_dataset,
                 nb_cases_validation_dataset,
                 dataset_name,
                 m,
                 tau,
                 kinematics_reference=1,
                 save=True,
                 model=model)

