import torch
from utils import mlp

model_name_baseline = 'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_2'
model_name_fine_tuned = 'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_3'

if torch.cuda.is_available():
    torch.cuda.set_device(1)
    print(torch.cuda.current_device())

learning_rate = 0.0001
nb_epoch = 40
model_layers = [512, 1024, 512]

datasets_path = 'mlp/files/datasets/'
neural_networks_path = 'mlp/files/neural_networks/'

# Dataset preparation
train_dataset = torch.load(datasets_path + model_name_fine_tuned + '/' + 'dataset_train.pt', weights_only=False)
validation_dataset = torch.load(datasets_path + model_name_fine_tuned + '/' + 'dataset_validation.pt', weights_only=False)

batch_size = 256 * 15

if torch.cuda.is_available():
    mlp.push_datasets_to_gpu(train_dataset, validation_dataset)

train_loader = torch.utils.data.DataLoader(dataset=train_dataset,
                                           batch_size=batch_size,
                                           shuffle=True,
                                           pin_memory=True)

validation_loader = torch.utils.data.DataLoader(dataset=validation_dataset,
                                                batch_size=batch_size,
                                                shuffle=True,
                                                pin_memory=True)

# Initialize the MLP
mlp_obj = mlp.TuningManagerMLP(n_input=len(train_dataset.__getitem__(0)[0]),
                               n_output=len(train_dataset.__getitem__(0)[1]),
                               layers_configuration=model_layers,
                               name=model_name_fine_tuned,
                               train_loader=train_loader,
                               validation_loader=validation_loader,
                               existing_model=model_name_baseline)

mlp_obj.save_mlp_parameters(neural_networks_path)
mlp_obj.print_model()

mlp_obj.set_training_hyperparameters(nb_epochs=nb_epoch,
                                     optimizer='adam',
                                     learning_rate=learning_rate,
                                     loss_function='MSE')

# Training
mlp_obj.start_training()
mlp_obj.save(neural_networks_path)

