import matplotlib.pyplot as plt
from utils import optimization
import numpy as np


model_name = 'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_0'
optimization_files_path = './files/aero/nsga2/'

optimization_name = '3d_theta_f_xf_u10_final_v3'
freestream_velocity = 10.0
chord = 0.25
h0_c = 0.5

X, F, bounds = optimization.load_results(path=optimization_files_path,
                                         model_name=model_name,
                                         optimization_name=optimization_name)

F_sorted = F[F[:, 0].argsort()]
X_sorted = X[F[:, 0].argsort()]
F = F_sorted
X = X_sorted

[xl, xu] = bounds

frequencies = X[:, 1]
pitching_amplitudes = X[:, 0]

filter_obj = np.logical_and(frequencies > 0.2, frequencies < 4.0)

frequencies_filtered = frequencies[filter_obj]
pitching_amplitudes_filtered = pitching_amplitudes[filter_obj]

heaving_objective_function = - F[:, 0]
pitching_objective_function = F[:, 1]

heaving_objective_function_filtered = heaving_objective_function[filter_obj]
pitching_objective_function_filtered = pitching_objective_function[filter_obj]

if np.size(X, 1) == 2:
    fig, axs = plt.subplots(1, 2, figsize=(12, 5))

    axs[0].scatter(pitching_amplitudes, frequencies, s=30, facecolors='none', edgecolors='r')
    axs[0].set_xlim(xl[0], xu[0])
    axs[0].set_ylim(xl[1], xu[1])
    axs[0].set_xlabel('Pitching Amplitude ($^{\circ}$)')
    axs[0].set_ylabel('Frequency ($Hz$)')
    axs[0].set_title("Design Space")
    axs[0].grid()

    axs[1].scatter(heaving_objective_function, pitching_objective_function, s=30, facecolors='none', edgecolors='blue')
    axs[1].set_xlabel('Recoverable Energy ($J$)')
    axs[1].set_ylabel('Consumed Energy ($J$)')
    axs[1].set_title('Objective Space')
    axs[1].set_xlim([heaving_objective_function.min(), heaving_objective_function.max()])
    axs[1].set_ylim([pitching_objective_function.min(), pitching_objective_function.max()])
    axs[1].grid()

    plt.suptitle("NACA0012 - $U_{\\infty} = 15.0$ $m.s^{-1}$ - $x_f/c = 0.3$ - $h/c = 0.5$", fontsize=10.5)

    plt.savefig(optimization_files_path + model_name + '/' + optimization_name + '/' + model_name + '.' + optimization_name + '.png',
                bbox_inches='tight')

elif np.size(X, 1) == 3:

    fig = plt.figure(figsize=(12, 5))
    ax1 = fig.add_subplot(1, 2, 1, projection='3d')
    ax1.view_init(elev=29, azim=-40, roll=0)
    colors = np.linspace(0, np.size(X, 0) - 1, np.size(X, 0))
    ax1.scatter(X[:, 0], (X[:, 1] * chord) / freestream_velocity, X[:, 2], c=colors, cmap='viridis')
    ax1.set_xlabel('$\\theta_0$ ($^{\circ}$)')
    ax1.set_ylabel('$f^{*} = \\frac{fc}{U_{\\infty}}$')
    ax1.set_zlabel('$x_f/c$ (-)')
    ax1.set_xlim(xl[0], xu[0])
    ax1.set_ylim((xl[1] * chord) / freestream_velocity, (xu[1] * chord) / freestream_velocity)
    ax1.set_zlim(xl[2], xu[2])
    ax1.set_title('Design Space')
    plt.subplots_adjust(wspace=0.5)

    ax2 = fig.add_subplot(1, 2, 2)
    ax2.scatter(heaving_objective_function, pitching_objective_function, s=30, c=colors, cmap='viridis')
    ax2.set_xlabel('Recoverable Energy ($J$)')
    ax2.set_ylabel('Consumed Energy ($J$)')
    ax2.set_title('Objective Space')
    ax2.set_xlim([heaving_objective_function.min(), heaving_objective_function.max()])
    ax2.set_ylim([pitching_objective_function.min(), pitching_objective_function.max()])
    ax2.grid()

    plt.suptitle("NACA0012 - $U_{\\infty} = $" + str(freestream_velocity) + " $m.s^{-1}$ - $h/c = $" + str(h0_c), fontsize=10.5)

    plt.savefig(optimization_files_path + model_name + '/' + optimization_name + '/' + model_name + '.' + optimization_name + '.png',
                bbox_inches='tight')

plt.show()