import numpy as np
from pymoo.algorithms.moo.nsga2 import NSGA2
from pymoo.operators.crossover.sbx import SBX
from pymoo.operators.mutation.pm import PM
from pymoo.operators.sampling.rnd import FloatRandomSampling
from pymoo.termination import get_termination
from pymoo.optimize import minimize
import torch
from utils import mlp, optimization

model_name = 'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_0'
neural_networks_path = '../mlp/files/neural_networks/'

optimization_name = '3d_theta_f_xf_u10_final_v4'
optimization_type = 'aero'

n_input, n_output, layers_configuration = mlp.load_parameters(neural_networks_path=neural_networks_path,
                                                              model_name=model_name)

model = mlp.MLP(n_input=n_input,
                n_output=n_output,
                layers_configuration=layers_configuration)

model.load_state_dict(torch.load(neural_networks_path + model_name + '/model_' + model_name + '.pt',
                                 weights_only=True))
model.eval()

problem = optimization.AeroMultiObjectivesProblem(model,
                                                  xl=np.array([0.0, 0.1, 0.05]),
                                                  xu=np.array([90.0, 10.0, 0.95]))

algorithm = NSGA2(pop_size=20,
                  n_offsprings=50,
                  sampling=FloatRandomSampling(),
                  crossover=SBX(prob=0.9, eta=15),
                  mutation=PM(eta=20),
                  eliminate_duplicates=True)

termination = get_termination("n_gen", 40)

res = minimize(problem,
               algorithm,
               termination,
               seed=1,
               save_history=True,
               verbose=True)

bounds = problem.bounds()

optimization.save_results(design_space=res.X,
                          optimization_functions=res.F,
                          bounds=bounds,
                          model_name=model_name,
                          optimization_name=optimization_name,
                          path='./files/' + optimization_type + '/nsga2/')
