import matplotlib.pyplot as plt
from utils import optimization
import numpy as np


model_name = 'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_5'
optimization_files_path = './files/dyn/nsga2/'

optimization_name = '3d_test_large'
chord = 0.25
h0_c = 0.5

u_inf = 10.0
m = 1.9
theta_0 = 79.5
xf_c = 0.32

X, F, bounds = optimization.load_results(path=optimization_files_path,
                                         model_name=model_name,
                                         optimization_name=optimization_name)

F_sorted = F[F[:, 0].argsort()]
X_sorted = X[F[:, 0].argsort()]
F = F_sorted
X = X_sorted

[xl, xu] = bounds

frequencies = X[:, 0]
C_h = X[:, 1]
K_h = X[:, 2]

xl[1] = 10.0
xu[1] = 22.5
xl[2] = 1500.0
xu[2] = 3500.0

reduced_frequency = ((2 * np.pi * frequencies) * (chord / 2)) / u_inf

xl[0] = ((2 * np.pi * 5.0) * (chord / 2)) / u_inf
xu[0] = ((2 * np.pi * 7.0) * (chord / 2)) / u_inf

heaving_objective_function = - F[:, 0]
pitching_objective_function =  - F[:, 1]

fig = plt.figure(figsize=(12, 5))
ax1 = fig.add_subplot(1, 2, 1, projection='3d')
ax1.view_init(elev=38, azim=-45, roll=0)
colors = np.linspace(0, np.size(X, 0) - 1, np.size(X, 0))
ax1.scatter(K_h, C_h, reduced_frequency, c=colors, cmap='viridis')
ax1.scatter(K_h, reduced_frequency, zdir='y', zs=xu[1], color='grey', alpha=0.3)
ax1.scatter(K_h, C_h, zdir='z', zs=xl[0], color='grey', alpha=0.3)
ax1.set_ylabel('$C_h$ ($N.s.m^{-2}$)')
ax1.set_xlabel('$K_h$ ($N.m^{-2}$)')
ax1.set_zlabel('$k$')
ax1.set_xlim(xl[2], xu[2])
ax1.set_ylim(xl[1], xu[1])
ax1.set_zlim(xl[0], xu[0])
ax1.set_title('Design Space', fontsize=9.5)
plt.subplots_adjust(wspace=0.5)

ax2 = fig.add_subplot(1, 2, 2)
ax2.scatter(- F[:, 0], - F[:, 1], s=30, c=colors, cmap='viridis')
ax2.set_xlabel('$P_e$ ($W.m^{-1}$)')
ax2.set_ylabel('Efficiency $\\eta$')
ax2.set_title('Objective Space', fontsize=9.5)
ax2.set_xlim([142.5, 185.0])
ax2.set_ylim([0.38, 0.46])
ax2.grid()

plt.suptitle('Step ' + model_name[-1] + ' | $U_{\\infty} = $' + str(u_inf) + ' $m.s^{-1}$ | $m = ' + str(m) + '$ $kg.m^{-1}$' + ' | $\\theta_0 = $' + str(np.round(theta_0, 2)) + '$^{\\circ}$ | $x_f/c = $' + str(xf_c),
             fontsize=9.5)

plt.savefig(optimization_files_path + 'figures/' + model_name + '.' + optimization_name + '.png',
            bbox_inches='tight')
plt.savefig(optimization_files_path + 'figures/' + model_name + '.' + optimization_name + '.svg',
            bbox_inches='tight')

plt.show()