import matplotlib.pyplot as plt
from utils import optimization
import numpy as np


model_name_list = ['outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_0',
                   'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_1',
                   'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_2',
                   'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_3',
                   'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_4',
                   'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_5']

colors = ['black', 'purple', 'blue', 'green', 'orange', 'red']
labels = ['Step 0', 'Step 1', 'Step 2', 'Step 3', 'Step 4', 'Step 5', 'Step 6', ]

optimization_files_path = './files/dyn/nsga2/'

optimization_name = '3d_test_large'
chord = 0.25
h0_c = 0.5

u_inf = 10.0
m = 1.9
theta_0 = 79.5
xf_c = 0.32

plt.figure()
plt.suptitle('$U_{\\infty} = $' + str(u_inf) + ' $m.s^{-1}$ | $m = ' + str(m) + '$ $kg.m^{-1}$' + ' | $\\theta_0 = $' + str(np.round(theta_0, 2)) + '$^{\\circ}$ | $x_f/c = $' + str(xf_c),
             fontsize=9.5)

plt.title('Objective Space', fontsize=9.5)
plt.xlim([142.5, 185.0])
plt.ylim([0.38, 0.46])
plt.grid()

F_1_avg = []
F_2_avg = []

for i in range(len(model_name_list)):
    model_name = model_name_list[i]
    X, F, bounds = optimization.load_results(path=optimization_files_path,
                                             model_name=model_name,
                                             optimization_name=optimization_name)

    F_sorted = F[F[:, 0].argsort()]
    X_sorted = X[F[:, 0].argsort()]
    F = F_sorted
    X = X_sorted

    if i >= 2:
        F_1_avg.append(F[:91, 0])
        F_2_avg.append(F[:91, 1])

    [xl, xu] = bounds

    frequencies = X[:, 0]

    plt.plot(- F[:, 0], - F[:, 1], c=colors[i], label=labels[i])

F_1_avg_values = np.mean(F_1_avg, axis=0)
F_2_avg_values = np.mean(F_2_avg, axis=0)

x = - F_1_avg_values
y = - F_2_avg_values
plt.plot(x, y, c='dimgrey', label='Avg.', linestyle='dashed')
plt.fill_between(x, y - 0.01, y + 0.01, linewidth=0, color='silver')
plt.fill_betweenx(y, x - 4.0, x + 4.0, linewidth=0, color='silver')

x1 = x
y1 = y
x1 = np.insert(x1, np.size(x1, 0), 142.5)
y1 = np.insert(y1, np.size(y1, 0), 0.455)
plt.fill_between(x1[-2:], y1[-2:] - 0.0075, y1[-2:] + 0.0075, linewidth=0, color='white')
x2 = x
y2 = y
x2 = np.insert(x2, 0, 174.5)
y2 = np.insert(y2, 0, 0.38)
plt.fill_betweenx(y2[:2], x2[:2] - 1.65, x2[:2] + 1.65, linewidth=0, color='white')

plt.xlabel('$P_e$ ($W.m^{-1}$)')
plt.ylabel('Efficiency $\\eta$')

plt.legend(fontsize=9.5)

plt.savefig(optimization_files_path + 'figures/global_pareto.png', bbox_inches='tight')
plt.savefig(optimization_files_path + 'figures/global_pareto.svg', bbox_inches='tight')

plt.show()

