import numpy as np
import torch
from matplotlib import pyplot as plt
from utils import aeroelasticity, kinematics, mlp, results, controller


frequency = 5.812756
K_h = 2415.15685
C_h = 18.712705

# Kinematics
pitching_amplitude = 79.5
rotation_axis_in_percentage_chord = 0.32

# Dynamical System
m = 1.9
K_theta = 0.0
C_theta = 0.0

model_name = 'outputs_cl_cm_inputs_xf_f_theta_ref_1_refined_5'
inputs_variables = ["x_f", "f", "theta_0"]
outputs_variable = ["lift_coefficient", "moment_coefficient"]

n_input, n_output, layers_configuration = mlp.load_parameters(neural_networks_path='mlp/files/neural_networks/',
                                                              model_name=model_name)

model = mlp.MLP(n_input=n_input,
                n_output=n_output,
                layers_configuration=layers_configuration)

model.load_state_dict(torch.load('mlp/files/neural_networks/' + model_name + '/model_' + model_name + '.pt',
                                 weights_only=True))
model.eval()

kinematics_obj = kinematics.Kinematics(kinematics_reference=1,
                                       nb_time_step_per_period=1000,
                                       input_variable_names=inputs_variables,
                                       output_variable_names=outputs_variable,
                                       variable_values=[rotation_axis_in_percentage_chord, frequency, pitching_amplitude],
                                       m=3,
                                       tau=9,
                                       nb_period=6)
kinematics_obj.generate_kinematics()

controller_obj = controller.PIDController(K_p=np.array([0.0, 500.0]),
                                          K_i=np.array([0.0, 75.0]),
                                          K_d=np.array([0.0, 10.0]),
                                          mode='semi_active')

dynamical_system_obj = aeroelasticity.DynamicalSystem(kinematics_obj=kinematics_obj,
                                                      model=model,
                                                      controller=controller_obj,
                                                      m=m,
                                                      K_h=K_h,
                                                      K_theta=K_theta,
                                                      C_h=C_h,
                                                      C_theta=C_theta)
try:
    dynamical_system_obj.motion_solver()
except:
    pass

dynamical_system_obj.show()
