import matplotlib.pyplot as plt
from utils import kinematics, ldvm, results
import numpy as np

inputs_variables = ["x_f", "f", "theta_0"]
outputs_variable = ["lift_coefficient", "moment_coefficient"]

variables = [0.3, 5.0, 70.0]

kinematics_obj = kinematics.Kinematics(kinematics_reference=1,
                                       nb_time_step_per_period=1000,
                                       input_variable_names=inputs_variables,
                                       output_variable_names=outputs_variable,
                                       variable_values=variables)

solver_input_data_dict = {
    'model': 'LDVM',
    'movement': {"frequency": kinematics_obj.frequency},
    'name': 'ldvm',
    'solver': {'duration': 2.0 / kinematics_obj.frequency,
               'nb_time_steps': 500},
    'airfoil': {'aileron_dimension_in_percentage_chord': 0.0,
                'chord': kinematics_obj.chord,
                'critical_lesp': 0.14,
                'rotation_axis_in_percentage_chord': kinematics_obj.rotation_axis_in_percentage_chord},
    'experimental_data': {'drag_coefficient': None,
                          'lift_coefficient': None,
                          'moment_coefficient': None},
    'flow': {'freestream_velocity': kinematics_obj.freestream_velocity,
             'surge_amplitude': 0.0,
             'surge_frequency': 0.0}
}

results_obj = ldvm.run_case(solver_input_data_dict, kinematics_obj, save_visualisation=True)
