import numpy as np


class PIDController:
    def __init__(self, K_p, K_i, K_d, mode):
        self.mode = mode
        self.K_p = K_p
        self.K_i = K_i
        self.K_d = K_d
        self.previous_error = 0.0
        self.integral = 0.0

    def compute(self, state_variable, reference, dt):
        # Calculate error
        h = state_variable[0]
        theta = state_variable[2]

        error = reference - np.array([h, theta])

        # Proportional term
        P_out = self.K_p * error

        # Integral term
        self.integral += error * dt
        I_out = self.K_i * self.integral

        # Derivative term
        derivative = (error - self.previous_error) / dt
        D_out = self.K_d * derivative

        # Compute total output
        control_output = P_out + I_out + D_out

        # Update previous error
        self.previous_error = error

        if self.mode == 'semi_active':
            control_output[0] = 0.0

        return control_output