import numpy as np
from matplotlib import pyplot as plt
from scipy.interpolate import griddata
from matplotlib import cm, colors
from scipy.interpolate import griddata

def plot_3d(x_arr, Z, v_min, v_max, label=None, suptitle=None, save_path=None):
    x = x_arr[:, 0]
    y = x_arr[:, 1]

    Z[Z < 0.0] = v_min
    Z[Z > 1.0] = v_min

    xi = np.linspace(x.min(), x.max(), 500)
    yi = np.linspace(y.min(), y.max(), 500)
    xi, yi = np.meshgrid(xi, yi, indexing='ij')

    zi = griddata(x_arr, Z, (xi, yi), method='cubic')

    fig, ax = plt.subplots(figsize=(9, 9), subplot_kw={"projection": "3d"}, dpi=100)

    fig.subplots_adjust(top=1.25)
    ax.view_init(elev=40, azim=-130, roll=0)
    ax.set_zlim([v_min, v_max])

    # cmap = cm.viridis
    cmap = cm.plasma
    ls = colors.LightSource(90, 45)

    colored_quantity = zi
    rgb = ls.shade(colored_quantity, cmap=cmap, blend_mode='soft', vmin=v_min, vmax=v_max)
    colorbar_label = '$\\eta$'

    norm = colors.Normalize(vmin=v_min, vmax=v_max)

    surf = ax.plot_surface(xi, yi, zi, facecolors=rgb, linewidth=0, antialiased=False, shade=False)
    cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap=cmap), ax=ax, label=colorbar_label, shrink=0.3, pad=0.02)

    ax.set_xlim([xi.min(), xi.max()])
    ax.set_ylim([yi.min(), yi.max()])

    ax.contourf(xi, yi, zi, zdir='x', offset=xi.max(), cmap='coolwarm')
    ax.contourf(xi, yi, zi, zdir='y', offset=yi.max(), cmap='coolwarm')

    ax.set_box_aspect((1.3, 1.3, 0.9), zoom=0.9)

    if suptitle is not None:
        fig.suptitle(suptitle, fontsize=10.0)

    if label is None:
        ax.set(xlabel="Var1", ylabel="Var2", zlabel="Output")
    else:
        ax.set(xlabel=label[0], ylabel=label[1], zlabel=label[2])

    if save_path is not None:
        plt.savefig(save_path, bbox_inches='tight', dpi=200)
