import numpy as np
import tqdm
from matplotlib import pyplot as plt
from matplotlib.animation import FuncAnimation

path = './files/8.0/'

output_visualisation = np.load(path + 'output_visualisation.npy')
output_data = np.load(path + 'output_data.npy')
# output_data = output_data[-251:, :]

time = output_data[:, 0]
period = time[-1] / 2.0

chord = 0.25

start_ind = np.where(np.isnan(output_visualisation[:, 0]))[0]
n_steps = len(start_ind) - 1

fig, ax = plt.subplots(1, 1, figsize=(20, 7), dpi=200)



plt.tight_layout()

plt.subplots_adjust(top=0.9, bottom=0.15, right=0.95, left=0.05)

ax.set_xlabel('$\\frac{x}{c}$')
ax.set_ylabel('$\\frac{y}{c}$')
text = ax.text(1.0,1.0,'', fontsize=14)

# ax.set_aspect('equal')

sc = ax.scatter([], [], c=[], s=1.5, cmap='jet', vmin=-0.01, vmax=0.01)

output_visualisation[:, 1] = output_visualisation[:, 1] / chord

def init():
    ax.set_xlim([- (output_data[-1, 0] * output_data[-1, 3]) / chord - 0.8 / chord, 0.8 / chord])
    ax.set_ylim([- output_data[:, 2].max() * 6.0, output_data[:, 2].max() * 6.0])
    return sc,

def save_images(n_steps):
    ax.set_xlim([- (output_data[-1, 0] * output_data[-1, 3]) / chord - 0.8 / chord, 0.8 / chord])
    ax.set_ylim([- output_data[:, 2].max() * 6.0, output_data[:, 2].max() * 6.0])
    for step in tqdm.tqdm(range(n_steps)):
        update(step)
        fig.savefig(path + 'images/im_' + str(step) + '.png', bbox_inches='tight', dpi=200)
        # plt.pause(0.001)

def update(step):
    text.set_text('$\\frac{t}{T} = $' + str(np.round(time[step] / period, 2)))
    vort = output_visualisation[start_ind[step] + 1:start_ind[step + 1], :]

    sc.set_offsets(vort[:, 1:3])
    sc.set_array(vort[:, 0])

    return sc, text

save_images(n_steps)

# ani = FuncAnimation(fig, update, frames=list(range(n_steps)), init_func=init, blit=True, interval=40.0)
# ani.save(filename=path + 'example.mp4', writer="ffmpeg")