# Modeling of a Semi-Active Flapping Foil Power Generator using Deep Learning

**Abstract:** Flapping foils are well known for their potential of harvesting energy. One practical way is to recover the energy from the heaving motion through a semi-activated foil for which the pitching motion is prescribed. This paper develops a more realistic representation of such system by modeling the aeroelasticity of a Flapping Foil Power Generator (FFPG) using Deep Learning. Given the advantage of leading edge vortex for increasing the performance, LESP Discrete Vortex Method is found to be a suitable model for predicting the aerodynamic loads acting on the foil. The coupling between the structure and the aerodynamic model is performed with a Feedforward Neural Network (FNN). An Active Learning procedure ensures the convergence on the modeling of the fluid-structure interaction. A multi-objective optimization conducted with a genetic algorithm (NSGA2) allowed to identify the primary parameters driving such system, namely the reduced frequency $k$, the stiffness $K_h$ and the pitching amplitude $\theta_0$. This study demonstrates that both the aerodynamical effects associated to dynamic stall and the natural excitation of the system must be exploited to optimize the efficiency of such FFPG. A simple relation is derived to optimize the reduced frequency to take advantage of the leading edge vortex that is developing on the foil undergoing significantly large pitching amplitudes.

## Requirements

Please follow these steps before using the project:

conda create -n oscillating_foil python=3.11 \
conda activate oscillating_foil \
pip install -r "requirements.txt"

For using the Machine Learning section of this project, the following commands have to be executed:

pip install torch~=2.5.1 \
conda install -c conda-forge mpi4py openmpi

A Fortran Compiler is required to run the LDVM model. Version used: **GNU Fortran (Ubuntu 7.5.0-3ubuntu1~18.04) 7.5.0**.\
Regarding the execution of the LDVM model, the original Fortran code is executed from Python in a temporary folder.

## LESP Discrete Vortex Method

Here is the reference to the method implemented in this project.

Ramesh K, Gopalarathnam A, Granlund K, Ol MV, Edwards JR. Discrete-vortex method with novel shedding criterion for unsteady aerofoil flows with intermittent leading-edge vortex shedding. Journal of Fluid Mechanics. 2014;751:500-538. doi:10.1017/jfm.2014.297

## Validation Data

LDVM model has been validated with experimental data from: Ōtomo, S., Henne, S., Mulleners, K. et al. Unsteady lift on a high-amplitude pitching aerofoil. Exp Fluids 62, 6 (2021). https://doi.org/10.1007/s00348-020-03095-2. The files related to LDVM validation are located in the **analysis/validation_ldvm** directory.

## Modify the Project

To modify the project, all the class and functions used are located in the **utils** directory.
